<?php

namespace Drupal\module_missing_message_fixer\Commands;

use Drush\Commands\DrushCommands;
use Drupal\module_missing_message_fixer\ModuleMissingMessageFixer;

/**
 * Class MmmfFixCommand
 *
 * @package Drupal\module_missing_message_fixer
 */
class MmmfFixCommand extends DrushCommands {

  /**
   * Fixes the missing modules.
   *
   * @param string $name
   *        The name of the module to fix messages for.
   *
   * @command module-missing-message-fixer:fix
   *
   * @option all Fixes all module missing messages.
   *
   * @usage drush module-missing-message-fixer:fix stuff
   *   Fixes the stuff module.
   * @usage drush module-missing-message-fixer:fix stuff --all
   *   Fixes all the modules.
   *
   * @aliases mmmff
   *
   */
  public function fixCommand($name = NULL, array $options = ['all' => NULL]) {
    $modules = [];
    $rows = ModuleMissingMessageFixer::checkModules(TRUE);
    if ($options['all'] !== NULL) {
      if (!empty($rows)) {
        foreach ($rows as $row) {
          $modules[] = $row['name'];
        }
      }
    }
    elseif ($name !== NULL) {
      // If this exists in the table.
      if (strpos(json_encode($rows), $name)) {
        $modules[] = $name;
      }
      else {
        drush_log(dt('Module ' . $name . ' was not found.'), 'error');
      }
    }
    else {
      drush_log(dt('Missing input, provide module name or run with --all'), 'error');
    }
    // Delete if there is no modules.
    if (count($modules) > 0) {
      $query = \Drupal::database()->delete('key_value');
      $query->condition('collection', 'system.schema');
      $query->condition('name', $modules, 'IN');
      $query->execute();

      if (drush_get_option('all') !== NULL) {
        drush_log(dt('All missing references have been removed.'), 'success');
      }
      elseif ($name !== NULL) {
        if (in_array($name, $modules, TRUE)) {
          drush_log(dt('Reference to ' . $name . ' (if found) has been removed.'), 'success');
        }
      }
    }
  }

}